#[non_exhaustive]pub enum Error {
Closed,
QueueFull,
Config {
message: &'static str,
},
PragmaUpdate {
name: &'static str,
exp: &'static str,
got: String,
},
Rusqlite(Error),
Panic {
message: String,
},
}Expand description
Enum of all possible errors.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
Closed
Indicates that the connection to the sqlite database is closed.
QueueFull
Indicates that the sqlite worker queue is full.
Config
Invalid builder configuration.
PragmaUpdate
Error updating PRAGMA.
Rusqlite(Error)
Represents a rusqlite::Error.
Panic
A user-provided closure panicked while being executed on the worker thread.